@@ -483,7 +483,7 @@ sub check_installed {
 
     $dirparts[-1] = 'arch'
       if $dirparts[-2] eq 'blib' && $dirparts[-1] eq 'lib';
-    warn "compare ".File::Spec->catfile(@endparts)." to $realname";
+    #warn "compare ".File::Spec->catfile(@endparts)." to $realname";
     File::Spec->catfile(@endparts) eq $realname
       or croak M28_error_grokking_path($realpath);
     $realpath =
@@ -498,7 +498,7 @@ sub check_installed {
     my $suffix = $Config{dlext};
     my $obj = File::Spec->catfile($realpath,'auto',$o->{API}{modpname},
                                   "$o->{API}{modfname}.$suffix");
-    warn "Want to find $obj";
+    #warn "Want to find $obj";
     croak M30_error_no_obj($o->{CONFIG}{NAME}, $o->{API}{pkg},
                            $realpath) unless -f $obj;
 
