@@ -2,6 +2,7 @@ package OpenGL::Sandbox;
 use v5.14; # I can aim for older upon request.  Not expecting any requests though.
 use Exporter::Extensible -exporter_setup => 1;
 use Try::Tiny;
+use File::Spec::Functions qw/ catpath splitpath catdir splitdir /;
 use Cwd 'abs_path';
 use Carp;
 use Log::Any '$log';
@@ -10,7 +11,7 @@ use Scalar::Util 'weaken';
 
 # ABSTRACT: Rapid-prototyping utilities for OpenGL
 BEGIN {
-our $VERSION = '0.100'; # VERSION
+our $VERSION = '0.110'; # VERSION
 }
 
 # Choose OpenGL::Modern if available, else fall back to OpenGL.
@@ -192,11 +193,20 @@ sub warn_gl_errors {
 }
 
 # Pull in the C file and make sure it has all the C libs available
-use OpenGL::Sandbox::Inline
-	C => do { my $x= __FILE__; $x =~ s|\.pm|\.c|; abs_path($x) },
-	INC => '-I'.do{ my $x= __FILE__; $x =~ s|/[^/]+$|/|; abs_path($x) }.' -I/usr/include/ffmpeg',
-	LIBS => '-lGL -lswscale',
-	CCFLAGSEX => '-Wall -g3 -Os';
+use Devel::CheckOS 'os_is';
+use OpenGL::Sandbox::Inline do {
+	my $src_dir= abs_path(catpath( (splitpath(__FILE__))[0,1] ));
+	my $src= catdir($src_dir, 'Sandbox.c');
+	my $libs= os_is('MSWin32')? '-lopengl32 -lgdi32 -lmsimg32' : '-lGL';
+	# Inline::C can take a file path, but it mistakes Win32 absolute paths for C code,
+	# so just slurp the file directly.
+	$src= do { local $/= undef; open my $fh, '<', $src; <$fh> } if os_is('MSWin32');
+	
+	C => $src,
+	INC => '-I'.$src_dir.' -I'.catdir($src_dir, qw( .. .. inc )),
+	#CCFLAGSEX => '-Wall -g3 -Os'
+	LIBS => $libs;
+};
 
 
 require OpenGL::Sandbox::ResMan;
@@ -215,7 +225,7 @@ OpenGL::Sandbox - Rapid-prototyping utilities for OpenGL
 
 =head1 VERSION
 
-version 0.100
+version 0.110
 
 =head1 SYNOPSIS
 
